AshSql.TypedStructArrayJsonb
(ash_sql v0.5.0)
A custom type for handling arrays of typed structs stored as JSONB in Postgres.
This type behaves similarly to Ash.Type.Map but expects a list of maps
(dumped typed structs) instead of a single map. It's used internally by
AshSql to properly cast typed struct arrays when stored as JSONB.